@@ -11,9 +11,9 @@ from scrapemove.models.common import (
 
 class Sizing(CamelCaseBaseModel):
     unit: str
-    displayUnit: str
-    minimumSize: float
-    maximumSize: float
+    display_unit: str
+    minimum_size: float
+    maximum_size: float
 
 
 class Station(CamelCaseBaseModel):
